@@ -152,8 +152,18 @@ class NamespaceDict(dict):
         self[k] = v
 
     def __getattr__(self, k: str):
+        if k.startswith("__") and k.endswith("__"):
+            return super().__getattribute__(k)
         return self[k]
 
+    def __copy__(self):
+        return NamespaceDict(self.copy())
+
+    def __deepcopy__(self, memodict=None):
+        if memodict is None:
+            memodict = {}
+        return NamespaceDict(copy.deepcopy(self.copy(), memodict))
+
 
 def __change_case(data, attr, preserve_dict_class=False):
     """
